function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import PropTypes from 'prop-types';
import { isDarkMode } from '@cloudflare/style-const';
import { createStyledComponent } from '@cloudflare/style-container';
import { transparentize } from 'polished';

var hueColors = hue => {
  switch (hue) {
    case 'red':
      return isDarkMode() ? {
        backgroundColor: 'red.3',
        color: 'gray.9'
      } : {
        backgroundColor: 'red.8',
        color: 'red.1'
      };

    case 'blue':
      return isDarkMode() ? {
        backgroundColor: 'blue.3',
        color: 'blue.9'
      } : {
        backgroundColor: 'blue.8',
        color: 'blue.1'
      };

    case 'green':
      return isDarkMode() ? {
        backgroundColor: 'green.3',
        color: 'gray.9'
      } : {
        backgroundColor: 'green.8',
        color: 'green.0'
      };

    case 'orange':
      return isDarkMode() ? {
        backgroundColor: 'orange.2',
        color: 'gray.9'
      } : {
        backgroundColor: 'orange.8',
        color: 'orange.1'
      };

    default:
      return isDarkMode() ? {
        backgroundColor: 'gray.2',
        color: 'gray.9'
      } : {
        backgroundColor: 'gray.8',
        color: 'gray.1'
      };
  }
};

var toHexString = (themeColor, theme) => {
  var [color, scale] = themeColor.split('.');
  return theme.colors[color][scale];
};

var styles = _ref => {
  var {
    theme,
    hue = 'gray',
    pulse = false
  } = _ref;
  var {
    color,
    backgroundColor
  } = hueColors(hue);
  return _objectSpread({
    alignItems: 'center',
    borderRadius: '50px',
    color,
    display: 'inline-flex',
    fontSize: 1,
    fontWeight: 400,
    lineHeight: theme.lineHeights.solid,
    userSelect: 'none',
    whiteSpace: 'nowrap',
    px: 2,
    py: 1,
    backgroundColor
  }, pulse && {
    animationName: {
      '0%': {
        boxShadow: "0 0 0 0 ".concat(transparentize(0.4, toHexString(backgroundColor, theme)))
      },
      '70%': {
        boxShadow: "0 0 0 10px ".concat(transparentize(1, toHexString(backgroundColor, theme)))
      },
      '100%': {
        boxShadow: "0 0 0 0 ".concat(transparentize(1, toHexString(backgroundColor, theme)))
      }
    },
    animationDuration: '2s',
    animationIterationCount: 'infinite'
  });
};

var Label = createStyledComponent(styles, 'span');
Label.propTypes = {
  hue: PropTypes.oneOf(['green', 'orange', 'red', 'gray', 'blue']).isRequired
};
export default Label;